@@ -42,6 +42,7 @@ class DocumentList {
 	void loadDoc (
 		Glib::ustring const &filename,
 		Glib::ustring const &relfilename,
+		Glib::ustring const &notes,
 		Glib::ustring const &key,
 		std::vector<int> const &taguids,
 		BibData const &bib);
@@ -51,7 +52,7 @@ class DocumentList {
 	void clear () {docs_.clear ();}
 
 	int importFromFile (Glib::ustring const &filename, BibUtils::Format format);
-	int import (std::string const &rawtext, BibUtils::Format format);
+	int import (Glib::ustring const &rawtext, BibUtils::Format format);
 	Document parseBibUtils (BibUtils::fields *ref);
 };
 
