@@ -13,49 +13,60 @@
 #ifndef DOCUMENTPROPERTIES_H
 #define DOCUMENTPROPERTIES_H
 
+#include <map>
+
 #include <libglademm.h>
 #include <gtkmm.h>
 
+#include "CaseFoldCompare.h"
+
 class Document;
 
 class DocumentProperties {
 	private:
 	Glib::RefPtr<Gnome::Glade::Xml> xml_;
 
-	Document *doc_;
-
+	/*
+	 * Local working copy
+	 */
 	Gtk::Dialog *dialog_;
-	Gtk::Entry *doientry_;
 	Gtk::Entry *keyentry_;
-	Gtk::Entry *titleentry_;
-	Gtk::Entry *authorsentry_;
-	Gtk::Entry *journalentry_;
-	Gtk::Entry *volumeentry_;
-	Gtk::Entry *issueentry_;
-	Gtk::Entry *pagesentry_;
-	Gtk::Entry *yearentry_;
 	Gtk::FileChooserButton *filechooser_;
+	Gtk::Image *iconImage_;
+
 	Gtk::Button *crossrefbutton_;
+	Gtk::Button *pastebibtexbutton_;
 	Gtk::Button *newextrafieldbutton_;
 	Gtk::Button *deleteextrafieldbutton_;
 	Gtk::Button *editextrafieldbutton_;
-	Gtk::ComboBoxEntryText *typecombo_;
 	Gtk::Expander *extrafieldsexpander_;
 	Gtk::TreeView *extrafieldsview_;
 	Glib::RefPtr<Gtk::TreeSelection> extrafieldssel_;
 
-  Gtk::TreeModelColumn<Glib::ustring> extrakeycol_;
-  Gtk::TreeModelColumn<Glib::ustring> extravalcol_;
-  Gtk::TreeModel::ColumnRecord cols_;
-  Glib::RefPtr< Gtk::ListStore > extrafieldsstore_;
+	Gtk::ComboBoxEntryText *typeCombo_;
+	typedef std::map <Glib::ustring, Gtk::Entry*, casefoldCompare> FieldEntryMap;
+	FieldEntryMap fieldEntries_;
 
-	void update ();
-	void save ();
-	void onCrossRefLookup ();
+	Gtk::TreeModelColumn<Glib::ustring> extrakeycol_;
+	Gtk::TreeModelColumn<Glib::ustring> extravalcol_;
+	Gtk::TreeModel::ColumnRecord cols_;
+	Glib::RefPtr< Gtk::ListStore > extrafieldsstore_;
+
+	void update (Document &doc);
+	void save (Document &doc);
+	void setupFields (Glib::ustring const &docType);
+	void onMetadataLookup ();
+	void onPasteBibtex ();
+	void onClear ();
 	void onNewExtraField ();
 	void onDeleteExtraField ();
 	void onEditExtraField ();
 	void onExtraFieldsSelectionChanged ();
+	void onExtraFieldEdited (const Glib::ustring& path, const Glib::ustring& text);
+	void onDoiEntryChanged ();
+	void updateSensitivity();
+	void onTypeChanged ();
+	bool ignoreTypeChanged_;
 
 	public:
 		bool show (Document *doc);
