@@ -18,14 +18,14 @@
 class Document;
 class DocumentList;
 class TagList;
-class TagWindow;
+class RefWindow;
 
 class Library {
 	public:
 	DocumentList *doclist_;
 	TagList *taglist_;
 
-	Library (TagWindow &tagwindow);
+	Library (RefWindow &tagwindow);
 	~Library ();
 
 	void clear ();
@@ -41,7 +41,6 @@ class Library {
 		bool const usebraces,
 		bool const utf8);
 
-
 	// The naming is BibtexFoo everywhere else, but in Library
 	// we use the manage_ prefix to be consistent with the file format
 	// which uses manage_ to be future-proof with more general manage
@@ -59,7 +58,7 @@ class Library {
 	Glib::ustring manage_target_;
 	bool manage_braces_;
 	bool manage_utf8_;
-	TagWindow &tagwindow_;
+	RefWindow &tagwindow_;
 };
 
 #endif
