@@ -36,12 +36,14 @@ class LibraryParser : public Glib::Markup::Parser {
 	bool inKey_;
 	bool inFileName_;
 	bool inRelFileName_;
+	bool inNotes_;
 	bool inTagged_;
 	bool inBibItem_;
 
 	Glib::ustring newDocKey_;
 	Glib::ustring newDocFileName_;
 	Glib::ustring newDocRelFileName_;
+	Glib::ustring newDocNotes_;
 	Glib::ustring newDocTag_;
 	std::vector<int> newDocTags_;
 	Glib::ustring bibText_;
@@ -66,6 +68,7 @@ class LibraryParser : public Glib::Markup::Parser {
 		inKey_ = false;
 		inFileName_ = false;
 		inRelFileName_ = false;
+		inNotes_ = false;
 		inTagged_ = false;
 		inBibItem_ = false;
 
@@ -108,12 +111,15 @@ class LibraryParser : public Glib::Markup::Parser {
 			newDocRelFileName_ = "";
 			newDocKey_ = "";
 			newDocTag_ = "";
+			newDocNotes_ = "";
 			newDocTags_.clear();
 			newDocBib_.clear();
 		} else if (inDoc_ && element_name == "filename") {
 			inFileName_ = true;
 		} else if (inDoc_ && element_name == "relative_filename") {
 			inRelFileName_ = true;
+		} else if (inDoc_ && element_name == "notes") {
+			inNotes_ = true;
 		} else if (inDoc_ && element_name == "key") {
 			inKey_ = true;
 		} else if (inDoc_ && element_name == "tagged") {
@@ -169,11 +175,13 @@ class LibraryParser : public Glib::Markup::Parser {
 		else if (element_name == "doc") {
 			inDoc_ = false;
 			doclist_.loadDoc (
-				newDocFileName_, newDocRelFileName_, newDocKey_, newDocTags_, newDocBib_);
+				newDocFileName_, newDocRelFileName_, newDocNotes_, newDocKey_, newDocTags_, newDocBib_);
 		} else if (inDoc_ && element_name == "filename") {
 			inFileName_ = false;
 		} else if (inDoc_ && element_name == "relative_filename") {
 			inRelFileName_ = false;
+		} else if (inDoc_ && element_name == "notes") {
+			inNotes_ = false;
 		} else if (inDoc_ && element_name == "key") {
 			inKey_ = false;
 		} else if (inDoc_ && element_name == "tagged") {
@@ -236,6 +244,8 @@ class LibraryParser : public Glib::Markup::Parser {
 			newDocFileName_ += text;
 		} else if (inRelFileName_) {
 			newDocRelFileName_ += text;
+		} else if (inNotes_) {
+			newDocNotes_ += text;
 		}
 		else if (inKey_)
 			newDocKey_ += text;
