@@ -111,9 +111,11 @@ private:
 	Gnome::Conf::Entry workoffline_;
 	Gnome::Conf::Entry uselistview_;
 	Gnome::Conf::Entry showtagpane_;
+	Gnome::Conf::Entry shownotespane_;
 	Gnome::Conf::Entry libraryfilename_;
 	Gnome::Conf::Entry width_;
 	Gnome::Conf::Entry height_;
+	Gnome::Conf::Entry notesheight_;
 
 	Gnome::Conf::Entry proxymode_;
 	Gnome::Conf::Entry proxyuseproxy_;
@@ -126,6 +128,7 @@ private:
 	sigc::signal<void> workofflinesignal_;
 	sigc::signal<void> uselistviewsignal_;
 	sigc::signal<void> showtagpanesignal_;
+	sigc::signal<void> shownotespanesignal_;
 	sigc::signal<void> plugindisabledsignal_;
 
 	bool ignoreChanges_;
@@ -160,11 +163,18 @@ public:
 	bool getShowTagPane ();
 	void setShowTagPane (bool const &showtagpane);
 	sigc::signal<void>& getShowTagPaneSignal ();
+	
+	bool getShowNotesPane ();
+	void setShowNotesPane (bool const &shownotespane);
+	sigc::signal<void>& getShowNotesPaneSignal ();
 
 	typedef std::pair<Glib::ustring, Glib::ustring> StringPair;
 
 	std::pair<int, int> getWindowSize ();
 	void setWindowSize (std::pair<int, int> size);
+	
+	int getNotesPaneHeight ();
+	void setNotesPaneHeight (int height);
 
 	bool const getFirstTime () {return firsttime_;}
 };
